summaryrefslogtreecommitdiffstats
path: root/kshowmail/kcmconfigs/configgeneral.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/kcmconfigs/configgeneral.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/kcmconfigs/configgeneral.h')
-rw-r--r--kshowmail/kcmconfigs/configgeneral.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/kshowmail/kcmconfigs/configgeneral.h b/kshowmail/kcmconfigs/configgeneral.h
index c61ef67..21c47bf 100644
--- a/kshowmail/kcmconfigs/configgeneral.h
+++ b/kshowmail/kcmconfigs/configgeneral.h
@@ -12,19 +12,19 @@
#ifndef CONFIGGENERAL_H
#define CONFIGGENERAL_H
-//Qt headers
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qtooltip.h>
-#include <qlabel.h>
+//TQt headers
+#include <ntqlayout.h>
+#include <ntqgroupbox.h>
+#include <ntqcheckbox.h>
+#include <ntqspinbox.h>
+#include <ntqtooltip.h>
+#include <ntqlabel.h>
//KDE headers
-#include <kcmodule.h>
-#include <kconfig.h>
+#include <tdecmodule.h>
+#include <tdeconfig.h>
#include <kgenericfactory.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
//KShowmail headers
#include <../constants.h>
@@ -33,7 +33,7 @@
* @brief Part of the setup dialog (KShowMailApp::SetupDialog) to configure general things.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
-class ConfigGeneral : public KCModule
+class ConfigGeneral : public TDECModule
{
Q_OBJECT
@@ -42,7 +42,7 @@ Q_OBJECT
/**
* Generic Constructor
*/
- ConfigGeneral( QWidget *parent = 0, const char *name = 0, const QStringList &args = QStringList() );
+ ConfigGeneral( TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList() );
/**
* Destructor
@@ -50,21 +50,21 @@ Q_OBJECT
~ConfigGeneral();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
*/
virtual void load();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
*/
virtual void defaults();
/**
* Overloaded method of KCModule.
* Stores the config information as shown in the user interface in the
* config file.
* Is called when the user clicks "Apply" or "Ok".
@@ -76,63 +76,63 @@ Q_OBJECT
/**
* Connector to the configuration file
*/
- KConfig* config;
+ TDEConfig* config;
/**
* Check box to select whether window closing must be confirmed.
*/
- QCheckBox* chkConfirmClose;
+ TQCheckBox* chkConfirmClose;
/**
* Check box to select whether deleting must be confirmed.
*/
- QCheckBox* chkConfirmDelete;
+ TQCheckBox* chkConfirmDelete;
/**
* Check box to select whether the main window will be minimized at start.
*/
- QCheckBox* chkStartMinimized;
+ TQCheckBox* chkStartMinimized;
/**
* Check box to select whether the close button leave the application running in tray.
*/
- QCheckBox* chkCloseToTray;
+ TQCheckBox* chkCloseToTray;
/**
* Check box to select whether minimizes to the tray rather than to the taskbar.
*/
- QCheckBox* chkMinimizeToTray;
+ TQCheckBox* chkMinimizeToTray;
/**
* Check box to select whether connection errors will be shown.
*/
- QCheckBox* chkShowConnectionErrors;
+ TQCheckBox* chkShowConnectionErrors;
/**
* Check box to select whether mails will be kept as new until termination.
*/
- QCheckBox* chkKeepNew;
+ TQCheckBox* chkKeepNew;
/**
* Spin box to set the initial timer.
*/
- QSpinBox* spbInitial;
+ TQSpinBox* spbInitial;
/**
* Spin box to set the interval timer.
*/
- QSpinBox* spbInterval;
+ TQSpinBox* spbInterval;
/**
* Spin box to set the time out timer.
*/
- QSpinBox* spbTimeout;
+ TQSpinBox* spbTimeout;
public slots:
/**
* Connected with the configuration items.
* Calls the slot changed() of KCModule to notify the dialog about the change.
*/
void slotChanged();
@@ -50,21 +50,21 @@ Q_OBJECT
~ConfigGeneral();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
@@ -50,21 +50,21 @@ Q_OBJECT
virtual void load();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
@@ -50,21 +50,21 @@ Q_OBJECT
virtual void defaults();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Stores the config information as shown in the user interface in the
* config file.
@@ -76,63 +76,63 @@ Q_OBJECT
/**
* Connected with the configuration items.
- * Calls the slot changed() of KCModule to notify the dialog about the change.
+ * Calls the slot changed() of TDECModule to notify the dialog about the change.
*/
void slotChanged();